@@ -1,5 +1,5 @@
 package Prometheus::Tiny::Shared;
-$Prometheus::Tiny::Shared::VERSION = '0.011';
+$Prometheus::Tiny::Shared::VERSION = '0.012';
 # ABSTRACT: A tiny Prometheus client with a shared database behind it
 
 use warnings;
@@ -68,6 +68,8 @@ sub _connect {
                     }
   );
 
+  $self->{dbh}->do('PRAGMA synchronous = OFF');
+
   $self->{dbh}->do(<<SQL);
     CREATE TABLE IF NOT EXISTS pts_store (
       name TEXT NOT NULL,
@@ -240,6 +242,10 @@ C<init_file>, if set to true, will overwrite any existing data file with the giv
 
 The C<cache_args> argument will cause the constructor to croak. Code using this arg in previous versions of Prometheus::Tiny::Shared no longer work, and needs to be updated to use the C<filename> argument instead.
 
+=head1 NOTES
+
+The on-disk backing store file is not intended to be a persistent, durable store (Prometheus will handle metrics resetting to zero correctly). For best performance, store it on some kind of memory-backed filesystem (eg Linux C<tmpfs>).
+
 =head1 SUPPORT
 
 =head2 Bugs / Feature Requests
